"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = verifyPrivateModularRoot;

var fs = _interopRequireWildcard(require("fs-extra"));

var path = _interopRequireWildcard(require("path"));

var logger = _interopRequireWildcard(require("../utils/logger"));

var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));

var _getWorkspaceInfo = _interopRequireDefault(require("../utils/getWorkspaceInfo"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

async function verifyPrivateModularRoot() {
  let valid = true;
  const modularRoot = (0, _getModularRoot.default)();
  const rootPackageJsonPath = path.join(modularRoot, 'package.json');
  const rootPackageJson = await fs.readJSON(rootPackageJsonPath);

  if (rootPackageJson.browserslist) {
    logger.debug(`Modular root has valid browserslist`);
  } else {
    const workspace = await (0, _getWorkspaceInfo.default)();

    for (const [packageName, worktree] of Object.entries(workspace)) {
      if (worktree.type === 'app') {
        const worktreePackageJson = await fs.readJson(path.join(modularRoot, worktree.location, 'package.json'));

        if (worktreePackageJson.browserslist) {
          logger.debug(`${packageName} has valid browserslist`);
        } else {
          logger.error(`${packageName} does not have browserslist set.`);
          valid = false;
        }
      }
    }
  }

  return valid;
}